@@ -28,6 +28,15 @@ USAGE() {
    echo "To make /dev/sde1 bootable on Linux:"
    echo "  $prog /dev/sde1"
 }
+# Check if root or not
+check_if_root() {
+   if [ ! "$UID" = "0" ]; then
+     echo
+     echo "[$LOGNAME] You need to run this script \"`basename $0`\" as root."
+     echo
+     exit 1
+   fi
+}
 #
 to_continue_or_not() {
   local prompt_msg="$1"
@@ -53,11 +62,13 @@ to_continue_or_not() {
             ;;
     esac
   done
-}
+} # end of to_continue_or_not
 
 #
 export LANG=C
 
+#
+check_if_root
 target_part="$1"
 
 #
